==> group_storage-3.0.0.zip: group_storage/src/Plugin/Group/Relation/GroupStorage.php <==
<?php

namespace Drupal\group_storage\Plugin\Group\Relation;

use Drupal\group\Plugin\Group\Relation\GroupRelationBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a group relation type for nodes.
 *
 * @GroupRelationType(
 *   id = "group_storage",
 *   label = @Translation("Group storage"),
 *   description = @Translation("Adds storage entities to groups both publicly and privately."),
 *   entity_type_id = "storage",
 *   entity_access = TRUE,
 *   reference_label = @Translation("Title"),
 *   reference_description = @Translation("The title of the storage to add to the group"),
 *   deriver = "Drupal\group_storage\Plugin\Group\Relation\GroupStorageDeriver",
 * )
 */
class GroupStorage extends GroupRelationBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    $config = parent::defaultConfiguration();
    $config['entity_cardinality'] = 1;
    return $config;
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {

    $form = parent::buildConfigurationForm($form, $form_state);

    // Disable the entity cardinality field as the functionality of this module
    // relies on a cardinality of 1. We don't just hide it, though, to keep a UI
    // that's consistent with other content enabler plugins.
    $info = $this->t("This field has been disabled by the plugin to guarantee the functionality that's expected of it.");
    $form['entity_cardinality']['#disabled'] = TRUE;
    $form['entity_cardinality']['#description'] .= '<br /><em>' . $info . '</em>';

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies() {
    $dependencies = parent::calculateDependencies();
    $dependencies['config'][] = 'storage.storage_type.' . $this->getRelationType()->getEntityBundle();
    return $dependencies;
  }

}

==> group_storage-3.1.0.zip: group_storage/src/Plugin/Group/Relation/GroupStorage.php <==
<?php

namespace Drupal\group_storage\Plugin\Group\Relation;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\group\Plugin\Attribute\GroupRelationType;
use Drupal\group\Plugin\Group\Relation\GroupRelationBase;
use Drupal\Core\Form\FormStateInterface;

#[GroupRelationType(
  id: 'group_storage',
  entity_type_id: 'storage',
  label: new TranslatableMarkup('Group storage'),
  description: new TranslatableMarkup('Adds storage entities to groups publicly and privately.'),
  reference_label: new TranslatableMarkup('Title'),
  reference_description: new TranslatableMarkup('The title of the storage to add to the group'),
  entity_access: TRUE,
  deriver: 'Drupal\group_storage\Plugin\Group\Relation\GroupStorageDeriver'
)]
class GroupStorage extends GroupRelationBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    $config = parent::defaultConfiguration();
    $config['entity_cardinality'] = 1;
    return $config;
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {

    $form = parent::buildConfigurationForm($form, $form_state);

    // Disable the entity cardinality field as the functionality of this module
    // relies on a cardinality of 1. We don't just hide it, though, to keep a UI
    // that's consistent with other content enabler plugins.
    $info = $this->t("This field has been disabled by the plugin to guarantee the functionality that's expected of it.");
    $form['entity_cardinality']['#disabled'] = TRUE;
    $form['entity_cardinality']['#description'] .= '<br /><em>' . $info . '</em>';

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies() {
    $dependencies = parent::calculateDependencies();
    $dependencies['config'][] = 'storage.storage_type.' . $this->getRelationType()->getEntityBundle();
    return $dependencies;
  }

}
